/*
 * Copyright (C) 2001, 2002 The Mir-coders group
 *
 * This file is part of Mir.
 *
 * Mir is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Mir is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Mir; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * In addition, as a special exception, The Mir-coders gives permission to link
 * the code of this program with  any library licensed under the Apache Software License,
 * The Sun (tm) Java Advanced Imaging library (JAI), The Sun JIMI library
 * (or with modified versions of the above that use the same license as the above),
 * and distribute linked combinations including the two.  You must obey the
 * GNU General Public License in all respects for all of the code used other than
 * the above mentioned libraries.  If you modify this file, you may extend this
 * exception to your version of the file, but you are not obligated to do so.
 * If you do not wish to do so, delete this exception statement from your version.
 */
package mircoders.localizer;

import java.util.List;

import mir.session.Request;
import mir.session.Session;
import mir.session.SessionHandler;
import mircoders.entity.EntityComment;
import mircoders.entity.EntityContent;

public interface MirOpenPostingLocalizer {

  /**
   *
   */
  public SessionHandler getOpenSessionHandler(Request aRequest, Session aSession) throws MirLocalizerExc, MirLocalizerFailure;

  /**
   * This method will be called after a comment has been posted
   * via the open posting interface.
   */
  public void afterCommentPosting(EntityComment aComment) throws MirLocalizerExc, MirLocalizerFailure;

  /**
   * This method will be called after an article is posted via the open posting interface.
   */
  public void afterArticlePosting(EntityContent anArticle) throws MirLocalizerExc, MirLocalizerFailure;

  /**
   *
   */

  public List getAntiAbuseFilterTypes() throws MirLocalizerExc, MirLocalizerFailure;

  /**
   * This method should return <code>true</code> if the article should be visible
   * to "open posting" users. This method is used to determine whether the request
   * for a pdf, or an email for the article should be allowed. It is however
   * <emph>not</emph> used by default by the production subsystem
   */
  public boolean allowArticlePublication(EntityContent anArticle);
}
